:mod:`langacore.kit.django.common.templatetags.converters`
==========================================================


.. automodule:: langacore.kit.django.common.templatetags.converters


Functions
----------

.. autofunction:: nullify

.. autofunction:: numberify

